@@ -183,13 +183,32 @@ def format_adaptation_detail(data):
         A pandas formatted DataFrame
     """
     df = pd.json_normalize([vars(o) for o in data]).explode('type').explode('scenario').reset_index(drop=True)
-    df['adaptationId'] = df['adaptationId'].astype('Int64').apply(str)
+    df['adaptationId'] = df['adaptationId'].apply(str)
     df['returnPeriod'] = df['returnPeriod'].astype('Int64').apply(str)
     df['geometry'] = df['geometry'].apply(get_geom_center)
+    if "serving" in df and df.serving.isnull().all():
+        df["serving_property"] = pd.NA
+        df["serving_neighborhood"] = pd.NA
+        df["serving_zcta"] = pd.NA
+        df["serving_tract"] = pd.NA
+        df["serving_city"] = pd.NA
+        df["serving_county"] = pd.NA
+        df["serving_cd"] = pd.NA
+        df["serving_state"] = pd.NA
+    else:
+        df = df.rename(columns={"serving.property": "serving_property",
+                                "serving.neighborhood": "serving_neighborhood",
+                                "serving.zcta": "serving_zcta",
+                                "serving.tract": "serving_tract",
+                                "serving.city": "serving_city",
+                                "serving.county": "serving_county",
+                                "serving.cd": "serving_cd",
+                                "serving.state": "serving_state"})
     df = pd.concat([df.drop(['geometry'], axis=1), df['geometry'].apply(pd.Series)], axis=1)
 
-    return df[['adaptationId', 'valid_id', 'name', 'type', 'scenario', 'conveyance', 'returnPeriod',
-               'latitude', 'longitude']]
+    return df[['adaptationId', 'valid_id', 'name', 'type', 'scenario', 'conveyance', 'returnPeriod', 'serving_property',
+               'serving_neighborhood', 'serving_zcta', 'serving_tract', 'serving_city', 'serving_county', 'serving_cd',
+               'serving_state', 'latitude', 'longitude']]
 
 
 def format_adaptation_summary(data):
@@ -532,7 +551,7 @@ def format_historic_event(data):
         df['propertiesTotal'] = pd.NA
         df['propertiesAffected'] = pd.NA
 
-    df['eventId'] = df['eventId'].astype('Int64').apply(str)
+    df['eventId'] = df['eventId'].apply(str)
     df['month'] = df['month'].astype('Int64').apply(str)
     df['year'] = df['year'].astype('Int64').apply(str)
     df['returnPeriod'] = df['returnPeriod'].astype('Int64').apply(str)
@@ -564,7 +583,7 @@ def format_historic_summary_property(data):
         df['depth'] = pd.NA
 
     df['fsid'] = df['fsid'].apply(str)
-    df['eventId'] = df['eventId'].astype('Int64').apply(str)
+    df['eventId'] = df['eventId'].apply(str)
     df['depth'] = df['depth'].astype('Int64').apply(str)
 
     return df[['fsid', 'valid_id', 'eventId', 'name', 'type', 'depth']]
@@ -593,7 +612,7 @@ def format_historic_summary(data):
         df['count'] = pd.NA
 
     df['fsid'] = df['fsid'].apply(str)
-    df['eventId'] = df['eventId'].astype('Int64').apply(str)
+    df['eventId'] = df['eventId'].apply(str)
     df['type'] = df['type'].apply(str)
     df['bin'] = df['bin'].astype('Int64').apply(str)
     df['count'] = df['count'].astype('Int64').apply(str)
